@@ -1,6 +1,6 @@
 package Config::Any::CSV;
 {
-  $Config::Any::CSV::VERSION = '0.02';
+  $Config::Any::CSV::VERSION = '0.03';
 }
 #ABSTRACT: Load CSV as config files
 
@@ -15,8 +15,10 @@ use Text::CSV;
 sub load {
     my ($class, $file, $driver) = @_;
 
+    my $with_key = 0;
     my $args = { binary => 1, allow_whitespace => 1 };
     if ($driver) {
+        $with_key = delete $driver->{with_key};
         $args->{$_} = $driver->{$_} for keys %$driver;
     }
     my $csv = Text::CSV->new( $args );
@@ -30,10 +32,12 @@ sub load {
         my $columns = scalar @$names - 1;
         while ( my $row = $csv->getline( $fh ) ) {
             next if @$row == 1 and $row->[0] eq ''; # empty line
-            $config->{ $row->[0] // "" } = {
+            my $id = $row->[0] // "";
+            $config->{ $id } = {
                 map { ( $names->[$_] // "" ) => ( $row->[$_] // $default ) }
                 (1..$columns)
             };
+            $config->{ $id }->{ $names->[0] // "" } = $id if $with_key;
         }
     }
     die $csv->error_diag() unless $csv->eof;
@@ -58,7 +62,7 @@ Config::Any::CSV - Load CSV as config files
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -75,10 +79,22 @@ I recommend to use L<Config::ZOMG>:
 
     # load foo.csv (and possible foo_local.csv)
     my $config = Config::ZOMG->new( 
-        path => '/path/to/config'
+        path => '/path/to/config',
         name => 'foo'
     );
 
+    # load with CSV options
+    my $config = Config::ZOMG->new( 
+        path => '/path/to/config',
+        name => 'foo',
+        drivers => {
+            CSV => { 
+                sep_char => ';', 
+                with_key => 1,
+            } 
+        }
+    );
+
 =head1 DESCRIPTION
 
 This small module adds support of CSV files to L<Config::Any>. Files with
@@ -106,6 +122,21 @@ Is parsed into this Perl structure:
         }
     }
 
+The driver option C<with_key> adds key field to each row:
+
+    {
+        alice => {
+            name => 'alice',
+            age  => '42',
+            mail => 'alice@example.org',
+        },
+         bob => {
+            name => 'bob',
+            age => '23',
+            mail => 'bob@example.org'
+        }
+    }
+
 The name of the first field is irrelevant and the order of rows gets lost. If a
 file contains multiple rows with the same first field value, only the last of
 these rows is used. Empty lines are ignored.
